Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2019-05-05 18:20:19 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2019-05-20 17:35:34 +0300
commitd2e139e44e0a3b70ae3b517c7b8f2449d3d1620c (patch)
tree8c5adc607e02db5975d96d7510e629c71e3a3b56 /source/blender/blenloader
parentb9ce1fee42291b174f1bdee2ae1fded8e9579937 (diff)
Color Management: update configuration, remove legacy transforms
* Replace Log view transform with Filmic Log. * Remove Rec.709, DCI-P3 displays that were incomplete and outdated. * Remove outdated RRT and Film transforms, replaced by Filmic. * Remove camera responsive curves that don't work with HDR colors. * Rename Default view transform to Standard. We're breaking compatibility now for 2.80, so that we can add future improvements on a clean config. Part of the code was contributed by George Vogiatzis in D4782. Differential Revision: https://developer.blender.org/D4900
Diffstat (limited to 'source/blender/blenloader')
-rw-r--r--source/blender/blenloader/intern/versioning_280.c26
-rw-r--r--source/blender/blenloader/intern/versioning_defaults.c4
2 files changed, 28 insertions, 2 deletions
diff --git a/source/blender/blenloader/intern/versioning_280.c b/source/blender/blenloader/intern/versioning_280.c
index 13ccc374073..c4e3390d65f 100644
--- a/source/blender/blenloader/intern/versioning_280.c
+++ b/source/blender/blenloader/intern/versioning_280.c
@@ -3461,6 +3461,32 @@ void blo_do_versions_280(FileData *fd, Library *UNUSED(lib), Main *bmain)
}
}
+ if (!MAIN_VERSION_ATLEAST(bmain, 280, 71)) {
+ /* This assumes the Blender builtin config. Depending on the OCIO
+ * environment variable for versioning is weak, and these deprecated view
+ * transforms and look names don't seem to exist in other commonly used
+ * OCIO configs so .blend files created for those would be unaffected. */
+ for (Scene *scene = bmain->scenes.first; scene; scene = scene->id.next) {
+ ColorManagedViewSettings *view_settings;
+ view_settings = &scene->view_settings;
+
+ if (STREQ(view_settings->view_transform, "Default")) {
+ STRNCPY(view_settings->view_transform, "Standard");
+ }
+ else if (STREQ(view_settings->view_transform, "RRT") ||
+ STREQ(view_settings->view_transform, "Film")) {
+ STRNCPY(view_settings->view_transform, "Filmic");
+ }
+ else if (STREQ(view_settings->view_transform, "Log")) {
+ STRNCPY(view_settings->view_transform, "Filmic Log");
+ }
+
+ if (STREQ(view_settings->look, "Filmic - Base Contrast")) {
+ STRNCPY(view_settings->look, "None");
+ }
+ }
+ }
+
{
/* Versioning code until next subversion bump goes here. */
}
diff --git a/source/blender/blenloader/intern/versioning_defaults.c b/source/blender/blenloader/intern/versioning_defaults.c
index c55a860f3b4..83a21a5480d 100644
--- a/source/blender/blenloader/intern/versioning_defaults.c
+++ b/source/blender/blenloader/intern/versioning_defaults.c
@@ -371,8 +371,8 @@ void BLO_update_defaults_startup_blend(Main *bmain, const char *app_template)
scene->r.displaymode = R_OUTPUT_WINDOW;
if (app_template && STREQ(app_template, "Video_Editing")) {
- /* Filmic is too slow, use default until it is optimized. */
- STRNCPY(scene->view_settings.view_transform, "Default");
+ /* Filmic is too slow, use standard until it is optimized. */
+ STRNCPY(scene->view_settings.view_transform, "Standard");
STRNCPY(scene->view_settings.look, "None");
}
else {